@@ -14,7 +14,7 @@ All of the API requests are created, and the API responses are parsed here.
 
 """
 
-__version__ = '0.2.9'
+__version__ = '0.2.10'
 
 import functools
 import json
@@ -84,13 +84,12 @@ class Intercom(object):
     def _call(cls, method, url, params=None):
         """ Construct an API request, send it to the API, and parse the
         response. """
-
         req_params = {}
         headers = {
             'User-Agent': 'python-intercom/' + __version__,
             'Accept': 'application/json'
         }
-        if method in ('POST', 'PUT'):
+        if method in ('POST', 'PUT', 'DELETE'):
             headers['content-type'] = 'application/json'
             req_params['data'] = json.dumps(params)
         elif method == 'GET':
@@ -187,15 +186,15 @@ class Intercom(object):
         >>> from datetime import datetime
         >>> import time
         >>> now = time.mktime(datetime.now().timetuple())
-        >>> user = Intercom.create_user(user_id='987', email='joe@example.com',
-        ... name='Joe Example', created_at=now, last_seen_ip='10.10.10.10',
-        ... custom_data={ 'job_type': 'smuggler'}, last_request_at=1350000000)
+        >>> user = Intercom.create_user(user_id='7902', email='ben@intercom.io',
+        ... name='Ben McRedmond', created_at=now, last_seen_ip='1.2.3.4',
+        ... custom_data={ 'plan': 'pro'}, last_request_at=1300000000)
         >>> user['name']
-        u'Joe Example'
-        >>> user['custom_data']['job_type']
-        u'smuggler'
+        u'Ben McRedmond'
+        >>> user['custom_data']['plan']
+        u'pro'
         >>> user['last_impression_at']
-        1350000000
+        1300000000
 
         """
         return Intercom._create_or_update_user('POST', **kwargs)
@@ -358,18 +357,17 @@ class Intercom(object):
 
     @classmethod
     def create_tag(
-            cls, name, tag_or_untag, user_ids=None, emails=None,
-            color=None):
+            cls, name, tag_or_untag, user_ids=None, emails=None):
         """ Create a tag (and maybe tag users).
 
         >>> tag = Intercom.create_tag("Free Trial", "tag",
         ... user_ids=["abc123", "def456"])
-        >>> tag.get('id', None)
+        >>> tag['id'] != None
+        True
         >>> tag['name']
         u'Free Trial'
-        >>> tag.get('tagged_user_count', None)
-        >>> tag['color']
-        u'green'
+        >>> tag['tagged_user_count']
+        2
 
         """
 
@@ -377,8 +375,7 @@ class Intercom(object):
             'name': name,
             'tag_or_untag': tag_or_untag,
             'user_ids': user_ids,
-            'emails': emails,
-            'color': color
+            'emails': emails
         }
         tag_dict = Intercom._call(
             'POST', Intercom.api_endpoint + 'tags', params=params)
@@ -386,18 +383,17 @@ class Intercom(object):
 
     @classmethod
     def update_tag(
-            cls, name, tag_or_untag, user_ids=None, emails=None,
-            color=None):
+            cls, name, tag_or_untag, user_ids=None, emails=None):
         """ Update a tag (and maybe tag users).
 
         >>> tag = Intercom.update_tag("Free Trial", "tag",
         ... user_ids=["abc123", "def456"])
-        >>> tag.get('id', None)
+        >>> tag['id'] != None
+        True
         >>> tag['name']
         u'Free Trial'
-        >>> tag.get('tagged_user_count', None)
-        >>> tag['color']
-        u'green'
+        >>> tag['tagged_user_count']
+        2
 
         """
 
@@ -405,8 +401,7 @@ class Intercom(object):
             'name': name,
             'tag_or_untag': tag_or_untag,
             'user_ids': user_ids,
-            'emails': emails,
-            'color': color
+            'emails': emails
         }
         tag_dict = Intercom._call(
             'PUT', Intercom.api_endpoint + 'tags', params=params)
@@ -417,12 +412,12 @@ class Intercom(object):
         """ Return a dict for the tag by the specified name.
 
         >>> tag = Intercom.get_tag(name="Free Trial")
-        >>> tag.get('id', None)
+        >>> tag['id'] != None
+        True
         >>> tag['name']
         u'Free Trial'
-        >>> tag.get('tagged_user_count', None)
-        >>> tag['color']
-        u'green'
+        >>> tag['tagged_user_count']
+        2
 
         """
 
